@@ -75,7 +75,6 @@ $CHROOT_CMD chmod u+x /sbin/ldconfig
 # Copy python wheels from build to final dir
 cp -Rp "$BUILDDIR/tmp/wheels" "$FINALDIR/tmp/wheelhouse"
 
-cp $WORKDIR/build_files/tgt.* $FINALDIR/tmp/builtin/optional
 cp $WORKDIR/build_files/qemu-utils.* $FINALDIR/tmp/builtin/optional
 cp $WORKDIR/build_files/lshw.* $FINALDIR/tmp/builtin/optional
 
@@ -129,7 +128,6 @@ if $INSTALL_SSH ; then
     fi
 fi
 
-$TC_CHROOT_CMD tce-load -ic /tmp/builtin/optional/tgt.tcz
 $TC_CHROOT_CMD tce-load -ic /tmp/builtin/optional/qemu-utils.tcz
 $TC_CHROOT_CMD tce-load -ic /tmp/builtin/optional/lshw.tcz
 if $TINYIPA_REQUIRE_BIOSDEVNAME; then
